@@ -1,9 +1,5 @@
 """ An editor manager that uses contributed editors. """
 
-
-# Standard library imports.
-import weakref
-
 # Enthought library imports.
 from enthought.pyface.workbench.api import EditorManager, TraitsUIEditor
 
@@ -11,20 +7,6 @@ from enthought.pyface.workbench.api import EditorManager, TraitsUIEditor
 class WorkbenchEditorManager(EditorManager):
     """ An editor manager that uses contributed editors. """
 
-    ###########################################################################
-    # 'object' interface.
-    ###########################################################################
-
-    def __init__(self, **traits):
-        """ Constructor. """
-
-        super(WorkbenchEditorManager, self).__init__(**traits)
-
-        # A mapping from editor to editor kind (the factory that created them).
-        self._editor_to_kind_map = weakref.WeakKeyDictionary()
-
-        return
-    
     ###########################################################################
     # 'IEditorManager' interface.
     ###########################################################################
@@ -36,8 +18,6 @@ class WorkbenchEditorManager(EditorManager):
         should be a callable with the following signature::
 
             callable(window=window, obj=obj) -> IEditor
-
-
         """
 
         if kind is None:
@@ -45,9 +25,7 @@ class WorkbenchEditorManager(EditorManager):
 
         editor = kind(window=window, obj=obj)
 
-        # Save the factory that created the editor so that we can allow the
-        # same object to be edited by different editors in the same window.
-        self._editor_to_kind_map[editor] = kind
+        self.add_editor(editor, kind)
         
         return editor
 
@@ -60,6 +38,6 @@ class WorkbenchEditorManager(EditorManager):
 
         if kind is None:
             kind = TraitsUIEditor
-        return self._editor_to_kind_map[editor] is kind and editor.obj == obj
+        return self.get_editor_kind(editor) is kind and editor.obj == obj
 
 #### EOF ######################################################################
