@@ -1,7 +1,13 @@
 # Standard library imports
-import os, sys
+from errno import EINTR
+import os
+import select
 import socket
 from subprocess import Popen
+import sys
+
+import csv
+import StringIO
 
 # ETS imports
 from enthought.etsconfig.api import ETSConfig
@@ -11,16 +17,43 @@ MESSAGE_SEP = chr(7) # 'bell' character
 
 # The location of the server lock file and the communication log
 LOCK_PATH = os.path.join(ETSConfig.application_data, 
-                                'remote_editor_server.lock')
+                         'remote_editor_server.lock')
 LOG_PATH = os.path.join(ETSConfig.application_data, 'remote_editor_server.log')
 
 
+def quoted_split(s):
+    f = StringIO.StringIO(s)
+    split = csv.reader(f, delimiter=' ', quotechar='"').next()
+    return split
+
+
 def spawn_independent(command, shell=False):
-    """ Given a command suitable for 'Popen', open the process such that when
-        this process is killed, the spawned process survives.
+    """ Given a command suitable for 'Popen', open the process such that if this
+        process is killed, the spawned process survives.
+        
+        `command` is either a list of strings, with the first item in the list being
+        the executable and the rest being its arguments, or a single string containing
+        the executable and its arguments.  In the latter case, any argument that
+        contains spaces must be delimited with double-quotes.
     """
     if sys.platform == 'win32':
-        Popen(command, shell=shell)
+        if isinstance(command, basestring):
+            command = 'start /b ' + command
+        else:
+            command.insert(0, 'start')
+            command.insert(1, '/b')
+        Popen(command, shell=True)
+    elif sys.platform == 'darwin':
+        pid = os.fork()
+        if pid:
+            return
+        else:
+            os.setpgrp()
+            if isinstance(command, basestring):
+                tmp = quoted_split(command)
+            else:
+                tmp = command
+            os.execv(tmp[0], tmp)
     else:
         pid = os.fork()
         if pid:
@@ -30,7 +63,6 @@ def spawn_independent(command, shell=False):
             Popen(command, shell=shell)
             sys.exit(0)
 
-
 def get_server_port():
     """ Reads the server port from the lock file. If the file does not exist
         returns -1.
@@ -45,10 +77,25 @@ def get_server_port():
         return -1
 
 
+def accept_no_intr(sock):
+    """ Call sock.accept such that if it is interrupted by an EINTR
+        ("Interrupted system call") signal or a KeyboardInterrupt exception, it
+        is re-called.
+    """
+    while True:
+        try:
+            return sock.accept()
+        except socket.error, err:
+            if err[0] != EINTR:
+                raise
+        except KeyboardInterrupt:
+            pass
+
+
 def send(sock, command, arguments=''):
     """ Send a command with arguments (both strings) through a socket. This
-        information is encoded with length information to ensure that
-        everything is recieved.        
+        information is encoded with length information to ensure that everything
+        is received.
     """
     sent, total = 0, 0
     msg = command + MESSAGE_SEP + arguments
@@ -58,7 +105,6 @@ def send(sock, command, arguments=''):
         msg = msg[sent:]
         sent = sock.send(msg)
         if not sent:
-            print "raised by Me"
             raise socket.error
         total += sent
 
@@ -84,19 +130,21 @@ def send_port(port, command, arguments='', timeout=None):
         except:
             pass
     return True
+
     
-def recieve(sock):
-    """ Recieve a command with arguments from a socket that was previously
-        sent information with 'send'.
-    """
-    # Use select to query the socket for activity before calling sock.recv
-    # Choose a timeout of 60. seconds for now.
-    import select
+def receive(sock):
+    """ Receive a command with arguments from a socket that was previously sent
+        information with 'send'.
+    """    
     index = -1
     chunk, length = '', ''
     received = False
+
     while not received:
+        # Use select to query the socket for activity before calling sock.recv.
+        # Choose a timeout of 60 seconds for now.
         readers, writers, in_error = select.select([sock], [], [], 60)
+
         for rsock in readers:
             while index == -1:
                 length += chunk
@@ -113,5 +161,6 @@ def recieve(sock):
                     raise socket.error
                 msg += chunk
             received = True
+
     command, sep, arguments = msg.partition(MESSAGE_SEP)
     return command, arguments
